![Project Logo](https://imgs.search.brave.com/lPl-BWFfBCvh025FDErfp0uAWDvVYXzi_YjqXf3AjRM/rs:fit:860:0:0:0/g:ce/aHR0cHM6Ly9jZG5h/Lmljb25zY291dC5j/b20vaW1nL2V4Y2x1/c2l2ZS4xZTFiZTQ3/LnN2Zw)

# PowerDecos

|         |Badges                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
|---------| |
| Testing | [![CI - Test](https://img.shields.io/codecov/c/github/MrCode200/power_decos?logo=codecov&label=Coverage)](https://app.codecov.io/github/MrCode200/power_decos)|
| Package | [![PyPI Latest Release](https://img.shields.io/pypi/v/power-decos)](https://pypi.org/project/power-decos/) [![PyPI Downloads](https://img.shields.io/pypi/dm/power-decos.svg?label=PyPI%20downloads)](https://pypi.org/project/power-decos/) ![Forks](https://img.shields.io/github/forks/MrCode200/power_decos?style=flat&label=Forks)
| Meta    |[![License - MIT](https://img.shields.io/github/license/MrCode200/power_decos)](https://github.com/MrCode200/power_decos/blob/main/LICENSE) ![Poetry](https://img.shields.io/badge/poetry-managed-blue)



A Python package full of various decorator utilities.


### It provides:

- Powerful, Simple but useful decorators

## Table of Contents

- [Installation](#installation)
- [Testing](#testing)
- [License](LICENSE.txt)
- [Documentation](#documentation)
- [Road Map](#road-map)
- [Getting Help](#getting-help)
- [Discussion and Development](#discussion-and-development)
- [Call for Contributions](#call-for-contributions)
- [Credits](#credits)
- [Getting Help](#getting-help)

### Installation

1. Ensure you have [Python](https://www.python.org/) installed.

   ```bash
    pip install git+https://github.com/MrCode200/power_decos.git   
   ```
   ```bash
    pip install power_decos
   ```

### Testing:

PowerDecos requires `pytest`. Tests can then be run after installation inside the package folder with:
- run:`pytest`
- or run: `poetry run pytest`
- to get a html coverage review add `--cov-report=html` to the end of `pytest`

## Documentation

- To view documentation in your website click [here](https://rawcdn.githack.com/MrCode200/power_deco/2ae2dfe5ec7338010a98d0f27f0fd0e7c618eadd/docs/html/index.html).

Or

- Run [index.html](docs/html/index.html) in your browser after cloning this project


## Road Map

1. [x] Add custom path to log decorator


## Call for Contributions

We’re excited that you’re interested in contributing to PowerDecos! Whether you’re fixing bugs, adding new features, improving documentation, or simply suggesting enhancements, your contributions are invaluable to us.


Every bit helps, and we appreciate your effort and enthusiasm!

Please refer to our [CONTRIBUTING.md](CONTRIBUTING.md) for more details.

## Credits

- No Credits yet

## Getting Help

For any questions or support, please first read our [FAQ.md](FAQ.md)

Then contact:

- **Your Name** - [luffydmoneky19992024@gmail.com](mailto:luffydmoneky19992024@gmail.com)
- **Project Link** - [https://github.com/MrCode200/power_deco](https://github.com/MrCode200/power_deco)
